CollectorExporter class

Implemented types

Constructors

CollectorExporter(Uri uri, {Client? httpClient, Map<String, String> headers = const {}, int timeoutMilliseconds = 10000})

Properties

client → Client
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutMilliseconds → int
Timeout duration for the request in milliseconds. Default is 10000ms. Set to 0 or a negative value to disable timeout.
final
uri → Uri
final

Methods

calculateJitteredDelay(int retries, Duration baseDelay) → Duration
export(List<ReadOnlySpan> spans) → void
override
forceFlush() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited